@@ -99,7 +99,7 @@ class NewsForm(TendenciBaseForm):
                                  ],
                       'legend': ''
                       }),
-                      ('Contact', {
+                      ('Author', {
                       'fields': ['first_name',
                                  'last_name',
                                  'google_profile',
